package com.example.watch_sdk;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;

import com.crrepa.ble.CRPBleClient;
import com.crrepa.ble.scan.bean.CRPScanDevice;
import com.crrepa.ble.scan.callback.CRPScanCallback;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

import java.util.List;

import androidx.core.app.ActivityCompat;
import io.flutter.plugin.common.EventChannel;

public class ScanDeviceManager {
    private static final int REQUEST_UPDATE_BAND_CONFIG = 4;
    private static final String[] PERMISSION_UPDATE_BAND_CONFIG = new String[] {
            "android.permission.WRITE_EXTERNAL_STORAGE",
            "android.permission.READ_EXTERNAL_STORAGE",
            "android.permission.ACCESS_FINE_LOCATION",
            "android.permission.ACCESS_COARSE_LOCATION"};

    private static final int SCAN_PERIOD = 10 * 1000;
    private Activity mActivity;
    private CRPBleClient mBleClient;
    private EventChannel.EventSink mEventSink;

    public ScanDeviceManager(Activity activity, EventChannel.EventSink eventSink) {
        mActivity = activity;
        mEventSink = eventSink;
        init();
    }

    public void init() {
        mBleClient = CRPBleClient.create(mActivity.getApplicationContext());
        requestPermissions();
    }

    public void startScan() {
        boolean success = mBleClient.scanDevice(new CRPScanCallback() {
            @Override
            public void onScanning(CRPScanDevice device) {
                Log.d("onScanning", "address: " + device.getDevice().getAddress());
                sendScanDeviceEvent(device);
            }

            @Override
            public void onScanComplete(List<CRPScanDevice> list) {

            }
        }, SCAN_PERIOD);

        /*if (success) {
            mBinding.btnScanToggle.setTag(null);
            mResultsAdapter.clearScanResults();
        }*/
    }

    public void cancelScan() {
        mBleClient.cancelScan();
    }

    private void sendScanDeviceEvent(CRPScanDevice scanDevice) {
        if (mEventSink == null) {
            return;
        }
        Gson gson = new GsonBuilder()
                .setPrettyPrinting()
                .create();
        String scanDeviceJson = gson.toJson(scanDevice);
        /*Log.d("GsonBuilder", scanDeviceJson);
        ConstraintsMap paramsMap = new ConstraintsMap();
        paramsMap.putString("event", "ScanDeviceEvent");
        paramsMap.putString("scanDevice", scanDeviceJson);*/

        ConstraintsMap paramsMap = new ConstraintsMap();
        paramsMap.putString("event", "ScanDeviceEvent");
        paramsMap.putString("scanDeviceJson", scanDeviceJson);

        paramsMap.putString("address", scanDevice.getDevice().getName());
        String deviceName = scanDevice.getDevice().getName();
        if (!TextUtils.isEmpty(deviceName)) {
            paramsMap.putString("name", deviceName);
        }
        mEventSink.success(paramsMap.toMap());
    }

    public void requestPermissions() {
        if (!PermissionUtils.hasSelfPermissions(mActivity.getApplicationContext(), PERMISSION_UPDATE_BAND_CONFIG)) {
            ActivityCompat.requestPermissions(
                    mActivity, PERMISSION_UPDATE_BAND_CONFIG, REQUEST_UPDATE_BAND_CONFIG);
        }
    }
}
