package com.example.watch_sdk;

import android.app.Activity;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.NonNull;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * WatchSdkPlugin
 */
public class WatchSdkPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware, EventChannel.StreamHandler {
    private final static String TAG = WatchSdkPlugin.class.getSimpleName();
    private MethodChannel mChannel;
    private EventChannel mEventChannel;
    private EventChannel.EventSink mEventSink;
    private Activity mActivity;

    private ScanDeviceManager mScanDeviceManager;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        mChannel = new MethodChannel(binding.getBinaryMessenger(), "watch_sdk_method");
        mChannel.setMethodCallHandler(this);

        mEventChannel = new EventChannel(binding.getBinaryMessenger(), "watch_sdk_event");
        mEventChannel.setStreamHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        mChannel.setMethodCallHandler(null);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "getHelloWorld":
                result.success("Hello World!!!!!!!!!!");
                break;
            case "msg2Native":
                System.out.println("msg=" + call.argument("msg"));
                System.out.println("msg2=" + call.argument("msg2"));
                result.success(null);

                sendEvent();
                break;
            case "startScan":
                mScanDeviceManager.startScan();
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    private void sendEvent() {
        if (mEventSink == null) {
            return;
        }
        ConstraintsMap paramsMap = new ConstraintsMap();
        paramsMap.putString("event", "event1");
        paramsMap.putString("value", "value1");
        mEventSink.success(paramsMap.toMap());
        Toast.makeText(mActivity.getApplicationContext(), "aaaaaaa!!!!!!!!", Toast.LENGTH_SHORT).show();
    }

    @Override
    public void onListen(Object arguments, EventChannel.EventSink events) {
        Log.d(TAG, "onListen");
        mEventSink = events;

        mScanDeviceManager = new ScanDeviceManager(mActivity, mEventSink);
    }

    @Override
    public void onCancel(Object arguments) {
        mEventSink = null;
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        Log.d(TAG, "onAttachedToActivity");
        mActivity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {
        mScanDeviceManager = null;
        mActivity = null;
    }
}
