import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:watch_sdk/watch_sdk.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  String _helloWorld = 'Unknown';

  @override
  void initState() {
    super.initState();
    WatchSdk();
    initPlatformState();
    initHelloWorld();
  }

  Future<void> initPlatformState() async {
    String platformVersion;
    try {
      platformVersion =
          await WatchSdk.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  Future<void> initHelloWorld() async {
    String helloWorldStr;
    try {
      helloWorldStr =
          await WatchSdk.invokeHelloWorld ?? 'Unknown Str';
    } on PlatformException {
      helloWorldStr = 'Failed to get platform version.';
    }

    if (!mounted) return;

    setState(() {
      _helloWorld = helloWorldStr;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          // child: Text('Running on: $_platformVersion\n' + '$_helloWorld\n'),
          child: Column(
            children: <Widget>[
              Text('Running on: $_platformVersion'),

              Text(_helloWorld),

              RaisedButton(
                  child: const Text('msg2Native', style: TextStyle(fontSize: 16.0)),
                  onPressed: onBtnPressed),

              RaisedButton(
                  child: const Text('startScan', style: TextStyle(fontSize: 16.0)),
                  onPressed: onStartScan),

            ],
          ),
        ),
      ),
    );
  }

  Future<void> onBtnPressed() async {
    await WatchSdk.msg2Native('abc');
  }

  Future<void> onStartScan() async {
    await WatchSdk.startScan;
  }
}
