import 'dart:async';
import 'dart:convert';
import 'package:flutter/services.dart';
import 'package:watch_sdk/ScanDeviceManager.dart';

class WatchSdk {
  static const MethodChannel _channel = MethodChannel('watch_sdk_method');
  static const EventChannel _eventChannel = EventChannel('watch_sdk_event');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String?> get invokeHelloWorld async {
    final String? str = await _channel.invokeMethod('getHelloWorld');
    return str;
  }

  static Future<void> msg2Native(String msg) async {
    await _channel.invokeMethod(
        'msg2Native', <String, dynamic>{'msg': msg, 'msg2': '123'});
  }

  static Future<void> get startScan async {
    await _channel.invokeMethod('startScan');
  }

  WatchSdk() {
    initEvent();
  }

  void initEvent() {
    StreamSubscription<dynamic> _eventSubscription = _eventChannel
        .receiveBroadcastStream()
        .listen(eventListener, onError: errorListener);
  }

  static const JsonDecoder decoder = JsonDecoder();
  void eventListener(dynamic event) {
    Map<dynamic, dynamic> map = event;
    switch (map['event']) {
      case 'event1':
        print("event1,value:" + map['value']);
        break;

      case 'ScanDeviceEvent':
        String scanDeviceJson = map['scanDeviceJson'];
        ScanDeviceManager.recieveScanDeviceEvent(scanDeviceJson);

        if (map['name'] != null) {
          String adress = map['address'];
          String name = map['name'];
          print("address" + adress);
          print("name" + name);
        }
        break;
    }
  }

  void errorListener(Object error) {
    print(error);
    // final PlatformException exception = error;
    // throw exception;
  }
}
